TcpStream

Struct TcpStream 

pub struct TcpStream { /* private fields */ }

Implementations

Source

impl TcpStream

pub fn connect<A: ToSocketAddrs>(addr: A) -> Result<TcpStream>

Create a new TCP stream and issue a non-blocking connect to the specified address.

addr is an address of the remote host. Anything which implements ToSocketAddrs trait can be supplied for the address; see this trait documentation for concrete examples. In case ToSocketAddrs::to_socket_addrs() returns more than one entry, then the first valid and reachable address is used.

pub fn from_stream(stream: TcpStream) -> Result<TcpStream>

Creates a new TcpStream from a standard net::TcpStream.

This function is intended to be used to wrap a TCP stream from the standard library in the soio equivalent. The conversion here will automatically set stream to nonblocking and the returned object should be ready to get associated with an event loop.

Note that the TCP stream here will not have connect called on it, so it should already be connected via some other means (be it manually, the net2 crate, or the standard library).

pub fn peer_addr(&self) -> Result<SocketAddr>

Returns the socket address of the remote peer of this TCP connection.

pub fn local_addr(&self) -> Result<SocketAddr>

Returns the socket address of the local half of this TCP connection.

pub fn try_clone(&self) -> Result<TcpStream>

Creates a new independently owned handle to the underlying socket.

The returned TcpStream is a reference to the same stream that this object references. Both handles will read and write the same stream of data, and options set on one stream will be propagated to the other stream.

pub fn shutdown(&self, how: Shutdown) -> Result<()>

Shuts down the read, write, or both halves of this connection.

This function will cause all pending and future I/O on the specified portions to return immediately with an appropriate value (see the documentation of Shutdown).

pub fn set_nodelay(&self, nodelay: bool) -> Result<()>

Sets the value of the TCP_NODELAY option on this socket.

If set, this option disables the Nagle algorithm. This means that segments are always sent as soon as possible, even if there is only a small amount of data. When not set, data is buffered until there is a sufficient amount to send out, thereby avoiding the frequent sending of small packets.

pub fn nodelay(&self) -> Result<bool>

Gets the value of the TCP_NODELAY option on this socket.

For more information about this option, see set_nodelay.

pub fn set_ttl(&self, ttl: u32) -> Result<()>

Sets the value for the IP_TTL option on this socket.

This value sets the time-to-live field that is used in every packet sent from this socket.

pub fn ttl(&self) -> Result<u32>

Gets the value of the IP_TTL option for this socket.

For more information about this option, see set_ttl.

pub fn take_error(&self) -> Result<Option<Error>>

Get the value of the SO_ERROR option on this socket.

This will retrieve the stored error in the underlying socket, clearing the field in the process. This can be useful for checking errors between calls.

pub fn read_bufs(&self, bufs: &mut [&mut IoVec]) -> Result<usize>

Read in a list of buffers all at once.

This operation will attempt to read bytes from this socket and place them into the list of buffers provided. Note that each buffer is an IoVec which can be created from a byte slice.

The buffers provided will be filled in sequentially. A buffer will be entirely filled up before the next is written to.

The number of bytes read is returned, if successful, or an error is returned otherwise. If no bytes are available to be read yet then a “would block” error is returned. This operation does not block.

On Unix this corresponds to the readv syscall.

pub fn write_bufs(&self, bufs: &[&IoVec]) -> Result<usize>

Write a list of buffers all at once.

This operation will attempt to write a list of byte buffers to this socket. Note that each buffer is an IoVec which can be created from a byte slice.

The buffers provided will be written sequentially. A buffer will be entirely written before the next is written.

The number of bytes written is returned, if successful, or an error is returned otherwise. If the socket is not currently writable then a “would block” error is returned. This operation does not block.

On Unix this corresponds to the writev syscall.